@@ -15,13 +15,18 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat.h,v 1.32 2005/06/10 08:20:59 davyd Exp $
+ $Id: battstat.h,v 1.35 2005/07/09 05:48:58 ryanl Exp $
  */
 
+#ifndef _battstat_h_
+#define _battstat_h_
 
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include <panel-applet.h>
+#include <panel-applet-gconf.h>
+
 #define DEBUG 0
 
 #define PROGLEN 33.0
@@ -49,17 +54,8 @@ typedef enum
   STATUS_PIXMAP_NUM
 } StatusPixmapIndex;
 
-typedef enum
-{
-  BATTERY_HIGH     = 0,
-  BATTERY_LOW      = 1,
-  BATTERY_CRITICAL = 2,
-  BATTERY_CHARGING = 3
-} BatteryState;
-
 typedef struct
 {
-  BatteryState state;
   gboolean on_ac_power;
   gboolean charging;
   gboolean present;
@@ -95,14 +91,9 @@ typedef struct _ProgressData {
   GtkWidget *radio_text_1;
   GtkWidget *radio_text_2;
   GtkWidget *check_text;
-  GtkWidget *suspend_entry;
   GtkWidget *lowbatt_toggle;
   GtkWidget *full_toggle;
-  
   GtkWidget *hbox_ptr;
-  GtkWidget *combo_ptr;
-  GtkWidget *spin_ptr;
-  GtkWidget *label_ptr;
 
   /* flags set from gconf or the properties dialog */
   guint red_val;
@@ -116,7 +107,6 @@ typedef struct _ProgressData {
   gboolean showstatus;
   gboolean showbattery;
   AppletTextType showtext;
-  char *suspend_cmd;
 
   /* label changed type (% <-> h:mm) and must be refreshed */
   gboolean refresh_label;
@@ -161,7 +151,6 @@ typedef struct _ProgressData {
   /* last_* for the benefit of the check_for_updates function */
   guint last_batt_life;
   guint last_acline_status;
-  guint last_batt_state;
   StatusPixmapIndex last_pixmap_index;
   guint last_charging;
   guint last_minutes;
@@ -172,8 +161,11 @@ void prop_cb (BonoboUIComponent *, ProgressData *, const char *);
 
 /* battstat_applet.c */
 void reconfigure_layout( ProgressData *battstat );
+void battstat_show_help( ProgressData *battstat, const char *section );
 
 /* power-management.c */
 const char *power_management_getinfo( BatteryStatus *status );
 const char *power_management_initialise( void );
 void power_management_cleanup( void );
+
+#endif /* _battstat_h_ */
