@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.110 2005/06/09 08:42:59 kmaraas Exp $ */
+/* $Id: weather.c,v 1.112 2005/08/07 16:33:02 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -582,7 +582,7 @@ static gdouble t0(time_t date)
 
 
 
-static gboolean sun (time_t t, gdouble obsLat, gdouble obsLon,
+static gboolean calc_sun2 (time_t t, gdouble obsLat, gdouble obsLon,
 	  time_t *rise, time_t *set)
 {
     time_t gm_midn;
@@ -698,7 +698,7 @@ static gboolean sun (time_t t, gdouble obsLat, gdouble obsLon,
 static gboolean calc_sun (WeatherInfo *info)
 {
   return info->location->latlon_valid
-    && sun(info->update,
+    && calc_sun2(info->update,
 	   info->location->latitude, info->location->longitude,
 	   &info->sunrise, &info->sunset);
 }
@@ -944,49 +944,29 @@ static const gchar *temperature_string (gfloat far, TempUnit to_unit, gboolean r
     switch (to_unit) {
         case TEMP_UNIT_FAHRENHEIT:
 			if (!round) {
-                if ( strcmp (_("%.1f F"), "%.1f F") != 0 ) {
-                    /* TRANSLATOR: This is the temperature in degrees fahrenheit, use the degree */
-                    /* symbol Unicode 00B0 if possible */
-                    g_snprintf(buf, sizeof (buf), _("%.1f F"), far);
-                } else {
-                    g_snprintf(buf, sizeof (buf), "%.1f \302\260F", far);
-                }
+                /* TRANSLATOR: This is the temperature in degrees Fahrenheit (\302\260 is the degree symbol) */
+                g_snprintf(buf, sizeof (buf), _("%.1f \302\260F"), far);
             } else {
-                if ( strcmp (_("%dF"), "%dF") != 0 ) {
-                    /* TRANSLATOR: This is the temperature in degrees fahrenheit, use the degree */
-                    /* symbol Unicode 00B0 if possible */
-                    g_snprintf(buf, sizeof (buf), _("%dF"), (int)floor(far + 0.5));
-                } else {
-                    g_snprintf(buf, sizeof (buf), "%d\302\260F", (int)floor(far + 0.5));
-                }
+                /* TRANSLATOR: This is the temperature in degrees Fahrenheit (\302\260 is the degree symbol) */
+                g_snprintf(buf, sizeof (buf), _("%d \302\260F"), (int)floor(far + 0.5));
             }
             break;
         case TEMP_UNIT_CENTIGRADE:
             if (!round) {
-                if ( strcmp (_("%.1f C"), "%.1f C") != 0 ) {
-                    /* TRANSLATOR: This is the temperature in degrees centigrade , use the degree */
-                    /* symbol Unicode 00B0 if possible */
-                    g_snprintf (buf, sizeof (buf), _("%.1f C"), TEMP_F_TO_C(far));
-                } else { 
-                    g_snprintf (buf, sizeof (buf), "%.1f \302\260C", TEMP_F_TO_C(far));
-                }
+                /* TRANSLATOR: This is the temperature in degrees Celsius (\302\260 is the degree symbol) */
+                g_snprintf (buf, sizeof (buf), _("%.1f \302\260C"), TEMP_F_TO_C(far));
             } else {
-                if ( strcmp (_("%dC"), "%dC") != 0 ) {
-                    /* TRANSLATOR: This is the temperature in degrees centigrade , use the degree */
-                    /* symbol Unicode 00B0 if possible */
-                    g_snprintf (buf, sizeof (buf), _("%dC"), (int)floor(TEMP_F_TO_C(far) + 0.5));
-                } else { 
-                    g_snprintf (buf, sizeof (buf), "%d\302\260C", (int)floor(TEMP_F_TO_C(far) + 0.5));
-				}
+                /* TRANSLATOR: This is the temperature in degrees Celsius (\302\260 is the degree symbol) */
+                g_snprintf (buf, sizeof (buf), _("%d \302\260C"), (int)floor(TEMP_F_TO_C(far) + 0.5));
             }
             break;
         case TEMP_UNIT_KELVIN:
             if (!round) {
-                /* TRANSLATOR: This is the temperature in Kelvin */
+                /* TRANSLATOR: This is the temperature in kelvin */
                 g_snprintf (buf, sizeof (buf), _("%.1f K"), TEMP_F_TO_K(far));
             } else {
-                /* TRANSLATOR: This is the temperature in Kelvin */
-                g_snprintf (buf, sizeof (buf), _("%dK"), (int)floor(TEMP_F_TO_K(far)));
+                /* TRANSLATOR: This is the temperature in kelvin */
+                g_snprintf (buf, sizeof (buf), _("%d K"), (int)floor(TEMP_F_TO_K(far)));
             } 
             break;
 
