@@ -128,6 +128,7 @@ create_mixer_collection (void)
       num++;
 
       /* and recreate this object, since we give it to the mixer */
+      g_free (title);
       title = g_strdup_printf (gettext("Unknown Volume Control %d"), num);
       element = gst_element_factory_create (factory, title);
     }
@@ -157,7 +158,9 @@ gnome_volume_applet_factory (PanelApplet *applet,
   }
 
   elements = create_mixer_collection ();
-  return gnome_volume_applet_setup (GNOME_VOLUME_APPLET (applet), elements);
+  gnome_volume_applet_setup (GNOME_VOLUME_APPLET (applet), elements);
+
+  return TRUE;
 }
 
 PANEL_APPLET_BONOBO_FACTORY (
